# Scratch 3 OneGPIO Extension Servers

![](docs/images/extensions.png)

## Control your favorite physical computing device using Scratch 3.

## Windows, Mac *AND* Linux(including Raspberry Pi) Compatible

## For installation and usage, read the [Installation and User's Guide.](https://mryslab.github.io/s3-extend/)



